==> monodevelop_2.4+dfsg.orig.tar.gz: monodevelop-2.4/tests/UnitTests/MonoDevelop.Refactoring/IntroduceFormatItemRefactoringTests.cs <==
// 
// IntroduceFormatItemRefactoring.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2009 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using NUnit.Framework;
using MonoDevelop.Refactoring;
using System.Collections.Generic;
using MonoDevelop.Refactoring.IntroduceFormat;

namespace MonoDevelop.Refactoring.Tests
{
	[TestFixture()]
	public class IntroduceFormatItemRefactoringTests : UnitTests.TestBase
	{
		void TestIntroduceFormatItemRefactoring (string inputString, string outputString)
		{
			IntroduceFormatItemRefactoring refactoring = new IntroduceFormatItemRefactoring ();
			RefactoringOptions options = ExtractMethodTests.CreateRefactoringOptions (inputString);
			List<Change> changes = refactoring.PerformChanges (options, null);
			string output = ExtractMethodTests.GetOutput (options, changes);
			Assert.IsTrue (ExtractMethodTests.CompareSource (output, outputString), "Expected:" + Environment.NewLine + outputString + Environment.NewLine + "was:" + Environment.NewLine + output);
		}
		
		[Test()]
		public void IntroduceFormatItemRefactoringSimpleTest ()
		{
			TestIntroduceFormatItemRefactoring (@"class TestClass
{
	void Test ()
	{
		Console.WriteLine (""Hello <-World->!"");
	}
}
", @"class TestClass
{
	void Test ()
	{
		Console.WriteLine (string.Format (""Hello {0}!"", ""World""));
	}
}");
		}
		
		[Test()]
		public void IntroduceFormatItemRefactoringComplexTest ()
		{
			TestIntroduceFormatItemRefactoring (@"class TestClass
{
	void Test ()
	{
		Console.WriteLine (string.Format (""Hello {0}!. Here is a <-test->! "", ""World""));
	}
}
", @"class TestClass
{ 
	void Test ()
	{
		Console.WriteLine (string.Format (""Hello {0}!. Here is a {1}! "", ""World"", ""test""));
	}
}");
		}
		
	}
}

==> monodevelop_2.8.6.3+dfsg.orig.tar.gz: monodevelop-2.8.6.3/tests/UnitTests/MonoDevelop.Refactoring/IntroduceFormatItemRefactoringTests.cs <==
// 
// IntroduceFormatItemRefactoring.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2009 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using NUnit.Framework;
using MonoDevelop.Refactoring;
using System.Collections.Generic;
//using MonoDevelop.Refactoring.IntroduceFormat;

namespace MonoDevelop.Refactoring.Tests
{
	/*
	[TestFixture()]
	public class IntroduceFormatItemRefactoringTests : UnitTests.TestBase
	{
		void TestIntroduceFormatItemRefactoring (string inputString, string outputString)
		{
			IntroduceFormatItemRefactoring refactoring = new IntroduceFormatItemRefactoring ();
			RefactoringOptions options = ExtractMethodTests.CreateRefactoringOptions (inputString);
			List<Change> changes = refactoring.PerformChanges (options, null);
			string output = ExtractMethodTests.GetOutput (options, changes);
			Assert.IsTrue (ExtractMethodTests.CompareSource (output, outputString), "Expected:" + Environment.NewLine + outputString + Environment.NewLine + "was:" + Environment.NewLine + output);
		}
		
		[Test()]
		public void IntroduceFormatItemRefactoringSimpleTest ()
		{
			TestIntroduceFormatItemRefactoring (@"class TestClass
{
	void Test ()
	{
		Console.WriteLine (""Hello <-World->!"");
	}
}
", @"class TestClass
{
	void Test ()
	{
		Console.WriteLine (string.Format (""Hello {0}!"", ""World""));
	}
}");
		}
		
		[Test()]
		public void IntroduceFormatItemRefactoringComplexTest ()
		{
			TestIntroduceFormatItemRefactoring (@"class TestClass
{
	void Test ()
	{
		Console.WriteLine (string.Format (""Hello {0}!. Here is a <-test->! "", ""World""));
	}
}
", @"class TestClass
{ 
	void Test ()
	{
		Console.WriteLine (string.Format (""Hello {0}!. Here is a {1}! "", ""World"", ""test""));
	}
}");
		}
		
	}
*/
}
